@@ -7,6 +7,7 @@ EXTENSIONS = {
     'apinotes': {'text', 'apinotes'},
     'asar': {'binary', 'asar'},
     'avif': {'binary', 'image', 'avif'},
+    'avsc': {'text', 'avro-schema'},
     'bash': {'text', 'shell', 'bash'},
     'bat': {'text', 'batch'},
     'bats': {'text', 'shell', 'bash', 'bats'},
@@ -74,6 +75,7 @@ EXTENSIONS = {
     'gd': {'text', 'gdscript'},
     'gemspec': {'text', 'ruby'},
     'geojson': {'text', 'geojson', 'json'},
+    'ggb': {'binary', 'zip', 'ggb'},
     'gif': {'binary', 'image', 'gif'},
     'go': {'text', 'go'},
     'gotmpl': {'text', 'gotmpl'},
@@ -268,6 +270,7 @@ EXTENSIONS = {
     'woff2': {'binary', 'woff2'},
     'wsgi': {'text', 'wsgi', 'python'},
     'xhtml': {'text', 'xml', 'html', 'xhtml'},
+    'xacro': {'text', 'xml', 'urdf', 'xacro'},
     'xml': {'text', 'xml'},
     'xq': {'text', 'xquery'},
     'xql': {'text', 'xquery'},
@@ -326,6 +329,7 @@ NAMES = {
     '.prettierignore': {'text', 'gitignore', 'prettierignore'},
     '.pypirc': EXTENSIONS['ini'] | {'pypirc'},
     '.rstcheck.cfg': EXTENSIONS['ini'],
+    '.salt-lint': EXTENSIONS['yaml'] | {'salt-lint'},
     '.yamllint': EXTENSIONS['yaml'] | {'yamllint'},
     '.zlogin': EXTENSIONS['zsh'],
     '.zlogout': EXTENSIONS['zsh'],
@@ -369,6 +373,7 @@ NAMES = {
     'setup.cfg': EXTENSIONS['ini'],
     'sys.config': EXTENSIONS['erl'],
     'sys.config.src': EXTENSIONS['erl'],
+    'Vagrantfile': EXTENSIONS['rb'],
     'WORKSPACE': EXTENSIONS['bzl'],
     'wscript': EXTENSIONS['py'],
 }
